window.Gleam.initSearch([{"doc":"dot_env","title":"dot_env","content":"# dot_env\n\n&lt;!--toc:start--&gt;\n\n- [Quick start](#quick-start)\n- [Installation](#installation)\n&lt;!--toc:end--&gt;\n\n[![Package Version](https://img.shields.io/hexpm/v/dot_env)](https://hex.pm/packages/dotenv)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/dot_env/)\n\ndot_env is a port of the popular JavaScript [dotenv](https://github.com/motdotla/dotenv) package that helps you load environment variables from .env (or other) files.\n\n&gt; This package may support other formats in the future but for now, supports the popular .env format\n&gt;\n&gt; You can find the Javascript &quot;tests&quot; [here](https://github.com/aosasona/dot_js_test)\n\n## Quick start\n\n```gleam\nimport dot_env as dot\nimport dot_env/env\nimport gleam/io\n\npub fn main() {\n    dot.new()\n    |&gt; dot.set_path(&quot;path/to/.env&quot;)\n    |&gt; dot.set_debug(False)\n    |&gt; dot.load\n\n    // or dot_env.load_with_opts(dot_env.Opts(path: &quot;path/to/.env&quot;, debug: False, capitalize: False))\n    // or `dot_env.load_default()` to load the `.env` file in the root path\n\n    case env.get(&quot;MY_ENV_VAR&quot;) {\n        Ok(value) -&gt; io.println(value)\n        Error(_) -&gt; io.println(&quot;something went wrong&quot;)\n    }\n\n    let app_name = env.get_or(&quot;APP_NAME&quot;, &quot;my app name&quot;)\n    let port = env.get_int_or(&quot;PORT&quot;, 3000)\n    let enable_signup = env.get_bool_or(&quot;ENABLE_SIGNUP&quot;, True)\n\n    io.debug(app_name)\n    io.debug(port)\n    io.debug(enable_signup)\n\n    Nil\n}\n```\n\n## Installation\n\n```sh\ngleam add dot_env\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/dot_env&gt;.\n","url":"index.html"},{"doc":"dot_env/env","title":"get","content":"pub fn get(key: String) -&gt; Result(String, String)\n Get an environment variable (supports both Erlang and JavaScript targets)\n\n Example:\n \n import dot_env/env\n import gleam/io\n import gleam/result\n\n env.get(&quot;FOO&quot;)\n |&gt; result.unwrap(&quot;NOT SET&quot;)\n |&gt; io.println\n \nSynonyms:\ndot_env/env.get\ndot_env/env get","url":"dot_env/env.html#get"},{"doc":"dot_env/env","title":"get_bool","content":"pub fn get_bool(key: String) -&gt; Result(Bool, String)\n Get an environment variable as a boolean\nSynonyms:\ndot_env/env.get_bool\ndot_env/env get_bool","url":"dot_env/env.html#get_bool"},{"doc":"dot_env/env","title":"get_bool_or","content":"pub fn get_bool_or(key: String, default: Bool) -&gt; Bool\n Get an environment variable as a boolean or return a default value if it is not set\nSynonyms:\ndot_env/env.get_bool_or\ndot_env/env get_bool_or","url":"dot_env/env.html#get_bool_or"},{"doc":"dot_env/env","title":"get_int","content":"pub fn get_int(key: String) -&gt; Result(Int, String)\n Get an environment variable as an integer\nSynonyms:\ndot_env/env.get_int\ndot_env/env get_int","url":"dot_env/env.html#get_int"},{"doc":"dot_env/env","title":"get_int_or","content":"pub fn get_int_or(key: String, default: Int) -&gt; Int\n Get an environment variable as an integer or return a default value if it is not set\nSynonyms:\ndot_env/env.get_int_or\ndot_env/env get_int_or","url":"dot_env/env.html#get_int_or"},{"doc":"dot_env/env","title":"get_or","content":"pub fn get_or(key: String, default: String) -&gt; String\n Get an environment variable or return a default value if it is not set\nSynonyms:\ndot_env/env.get_or\ndot_env/env get_or","url":"dot_env/env.html#get_or"},{"doc":"dot_env/env","title":"get_then","content":"pub fn get_then(\n  key: String,\n  f: fn(String) -&gt; Result(a, String),\n) -&gt; Result(a, String)\n An alternative implementation of `get` that allows for chaining using `use`\nSynonyms:\ndot_env/env.get_then\ndot_env/env get_then","url":"dot_env/env.html#get_then"},{"doc":"dot_env/env","title":"set","content":"pub fn set(key: String, value: String) -&gt; Result(Nil, String)\n Set an environment variable (supports both Erlang and JavaScript targets)\n\n Example:\n \n import dot_env/env\n\n env.set(&quot;FOO&quot;, &quot;my value&quot;)\n \n\nSynonyms:\ndot_env/env.set\ndot_env/env set","url":"dot_env/env.html#set"},{"doc":"dot_env/env","title":"dot_env/env","content":"","url":"dot_env/env.html"},{"doc":"dot_env","title":"DotEnv","content":"pub opaque type DotEnv\n\n\nSynonyms:\ndot_env.DotEnv\ndot_env DotEnv","url":"dot_env.html#DotEnv"},{"doc":"dot_env","title":"Opts","content":"pub type Opts {\n  Opts(\n    path: String,\n    debug: Bool,\n    capitalize: Bool,\n    ignore_missing_file: Bool,\n  )\n  Default\n}\n\nOpts(\n  path: String,\n  debug: Bool,\n  capitalize: Bool,\n  ignore_missing_file: Bool,\n)\n Customized options for loading the .env file\npath\n&lt;p&gt;The path to the .env file relative to the project root eg. .env and src/.env are two different things, .env points to the root of the project, src/.env points to the src folder in the root of the project&lt;/p&gt;\n\ndebug\n&lt;p&gt;Print debug information if something goes wrong&lt;/p&gt;\n\ncapitalize\n&lt;p&gt;Force all keys to be uppercase&lt;/p&gt;\n\nignore_missing_file\n&lt;p&gt;In case the file is missing, ignore the error and continue&lt;/p&gt;\n\nDefault\n Default options for loading the .env file - see `default` constant\n\nSynonyms:\ndot_env.Opts\ndot_env Opts","url":"dot_env.html#Opts"},{"doc":"dot_env","title":"default","content":"pub const default: DotEnv\n\nSynonyms:\ndot_env.default\ndot_env default","url":"dot_env.html#default"},{"doc":"dot_env","title":"load","content":"pub fn load(dotenv: DotEnv) -&gt; Nil\n Load the .env file using the current DotEnv instance and set the environment variables\n\n # Example\n\n \n import dot_env as dot\n\n pub fn main() {\n   dot.new()\n   |&gt; dot.set_path(&quot;src/.env&quot;)\n   |&gt; dot.set_debug(False)\n   |&gt; dot.load\n }\nSynonyms:\ndot_env.load\ndot_env load","url":"dot_env.html#load"},{"doc":"dot_env","title":"load_default","content":"pub fn load_default() -&gt; Nil\n Load the .env file at the default path (.env) and set the environment variables\n\n Debug information will be printed to the console if something goes wrong and all keys will be capitalized\n\n # Example\n\n \n import dot_env\n\n pub fn main() {\n   dot_env.load_default()\n }\n \nSynonyms:\ndot_env.load_default\ndot_env load_default","url":"dot_env.html#load_default"},{"doc":"dot_env","title":"load_with_opts","content":"pub fn load_with_opts(opts: Opts) -&gt; Nil\n Load the .env file at the specified path and set the environment variables\n\n Debug information and key capitalization can be customized\n\n # Example\n\n \n import dot_env\n\n pub fn main() {\n   dot_env.load_with_opts(dot_env.Opts(path: &quot;src/.env&quot;, debug: False, capitalize: False))\n }\n \nSynonyms:\ndot_env.load_with_opts\ndot_env load_with_opts","url":"dot_env.html#load_with_opts"},{"doc":"dot_env","title":"new","content":"pub fn new() -&gt; DotEnv\n Create a default DotEnv instance. This is designed to use used as the starting point for using any of the builder methods\nSynonyms:\ndot_env.new\ndot_env new","url":"dot_env.html#new"},{"doc":"dot_env","title":"new_with_path","content":"pub fn new_with_path(path: String) -&gt; DotEnv\n Create a new DotEnv instance with the specified path\nSynonyms:\ndot_env.new_with_path\ndot_env new_with_path","url":"dot_env.html#new_with_path"},{"doc":"dot_env","title":"path","content":"pub fn path(instance: DotEnv) -&gt; String\n Get the path to the .env file in the current DotEnv instance\nSynonyms:\ndot_env.path\ndot_env path","url":"dot_env.html#path"},{"doc":"dot_env","title":"set_capitalize","content":"pub fn set_capitalize(\n  instance: DotEnv,\n  capitalize: Bool,\n) -&gt; DotEnv\n Set whether to capitalize all keys in the current DotEnv instance\nSynonyms:\ndot_env.set_capitalize\ndot_env set_capitalize","url":"dot_env.html#set_capitalize"},{"doc":"dot_env","title":"set_debug","content":"pub fn set_debug(instance: DotEnv, debug: Bool) -&gt; DotEnv\n Set whether to print debug information in the current DotEnv instance\nSynonyms:\ndot_env.set_debug\ndot_env set_debug","url":"dot_env.html#set_debug"},{"doc":"dot_env","title":"set_ignore_missing_file","content":"pub fn set_ignore_missing_file(\n  instance: DotEnv,\n  ignore_missing_file: Bool,\n) -&gt; DotEnv\n Set whether to ignore missing file errors in the current DotEnv instance\nSynonyms:\ndot_env.set_ignore_missing_file\ndot_env set_ignore_missing_file","url":"dot_env.html#set_ignore_missing_file"},{"doc":"dot_env","title":"set_path","content":"pub fn set_path(instance: DotEnv, path: String) -&gt; DotEnv\n Set the path to the .env file in the current DotEnv instance\nSynonyms:\ndot_env.set_path\ndot_env set_path","url":"dot_env.html#set_path"},{"doc":"dot_env","title":"dot_env","content":"","url":"dot_env.html"}]);